@@ -21,12 +21,8 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-structured-blob.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-infile-impl.h>
-#include <gsf/gsf-input.h>
-#include <gsf/gsf-outfile.h>
-#include <gsf/gsf-output.h>
-#include <gsf/gsf-shared-memory.h>
+#include <gsf/gsf.h>
+
 #include <string.h>
 
 static GObjectClass *parent_class;
@@ -67,7 +63,6 @@ blob_dup (GsfInput *input, G_GNUC_UNUSED GError **err)
 {
 	GsfStructuredBlob const *src = (GsfStructuredBlob *) input;
 	GsfStructuredBlob *dst = g_object_new (GSF_STRUCTURED_BLOB_TYPE, NULL);
-	if (G_UNLIKELY (NULL == dst)) return NULL;
 
 	if (src->data != NULL)
 		dst->data = g_object_ref (src->data);
@@ -210,7 +205,6 @@ gsf_structured_blob_read (GsfInput *input)
 	g_return_val_if_fail (GSF_IS_INPUT (input), NULL);
 
 	blob = g_object_new (GSF_STRUCTURED_BLOB_TYPE, NULL);
-	if (G_UNLIKELY (NULL == blob)) return NULL;
 
 	content_size = gsf_input_remaining (input);
 	if (content_size > 0) {
