@@ -230,6 +230,7 @@ gsf_init_dynamic (GTypeModule *module)
 
 /**
  * gsf_shutdown_dynamic:
+ * @module: currently unused
  *
  * De-intializes the GSF library from a type module.
  * Currently does nothing.
@@ -536,9 +537,9 @@ gsf_le_set_double (void *p, double d)
  * Extracts the extension from the end of a filename (the part after the final
  * '.' in the filename).
  *
- * Returns: A pointer to the extension part of the filename, or a
- * pointer to the end of the string if the filename does not
- * have an extension.
+ * Returns: (transfer none): A pointer to the extension part of the
+ * filename, or a pointer to the end of the string if the filename
+ * does not have an extension.
  */
 char const *
 gsf_extension_pointer (char const *path)
@@ -720,7 +721,7 @@ gsf_base64_decode_simple (guint8 *data, size_t len)
  * @p_params: a pointer to the GParameter array that holds the properties.
  *   (Used for both input and output.  This may point to a %NULL pointer if
  *   there are no properties collected yet.)
- * @first_property_name: the name of the first property being set, or NULL.
+ * @first_property_name: the name of the first property being set, or %NULL.
  * @var_args: a va_list holding the remainder of the property names and
  *   values, terminated by a %NULL.
  *
@@ -797,6 +798,20 @@ gsf_property_settings_collect (GType object_type,
   va_end (var_args);
 }
 
+const GParameter *
+gsf_property_settings_find (const char *name,
+			    const GParameter *params,
+			    size_t n_params)
+{
+	size_t i;
+
+	for (i = 0; i < n_params; i++)
+		if (g_str_equal (name, params[i].name))
+			return params + i;
+
+	return NULL;
+}
+
 void
 gsf_property_settings_free (GParameter *params,
 			    size_t n_params)
